Enum ebml_iterable::tags::TagData[][src]

pub enum TagData {
    Master(Vec<(u64, TagData)>),
    UnsignedInt(u64),
    Integer(i64),
    Utf8(String),
    Binary(Vec<u8>),
    Float(f64),
}
Contains the content of a tag.

This struct contains tag content data - i.e. the “meat” of the tag.

Note: This library made a concious decision to not parse “Date” elements from EBML due to lack of built-in support for dates in Rust. Specification implementations should treat Date elements as Binary so that consumers have the option of parsing the unaltered data using their library of choice, if needed.

Variants

Master(Vec<(u64, TagData)>)

A complete master tag containing any number of child tags.

UnsignedInt(u64)

An unsigned integer.

Integer(i64)

A signed integer.

Utf8(String)

A Unicode text string. Note that the [EBML spec][https://datatracker.ietf.org/doc/rfc8794/] includes a separate element type for ASCII. Given that ASCII is a subset of Utf8, this library currently parses and encodes both types using the same Utf8 element.

Binary(Vec<u8>)

Binary data, otherwise uninterpreted.

Float(f64)

IEEE-754 floating point number.

Implementations