Enum ebml_iterable::tags::TagPosition [−][src]
TagPosition is an enumeration containing three different tag “positions” that this library works with:
Variants
StartTag(u64)A marker for the beginning of a “master” tag as defined in EBML. Master tags are simply containers for other tags. The u64 value is the “id” of the tag.
EndTag(u64)A marker for the end of a “master” tag. The u64 value is the “id” of the tag.
A complete tag that includes both the id and full data of the tag. See TagData for more detail.
Implementations